@@ -5,7 +5,7 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
+ *  the Free Software Foundation; either version 3, or (at your option)
  *  any later version.
  *
  *  This program is distributed in the hope that it will be useful,
@@ -265,7 +265,11 @@ notebook_page_reordered_cb (GtkNotebook *notebook,
 
 static void
 notebook_page_switch_cb (GtkNotebook *notebook,
-                         GtkNotebookPage *page,
+#if GTK_CHECK_VERSION (2, 90, 6)
+                         GtkWidget *page,
+#else
+                         gpointer page,
+#endif
                          guint position,
                          TerminalTabsMenu *menu)
 {
@@ -273,7 +277,11 @@ notebook_page_switch_cb (GtkNotebook *notebook,
         TerminalScreen *screen;
         GtkAction *action;
 
+#if GTK_CHECK_VERSION (2, 90, 6)
+        container = TERMINAL_SCREEN_CONTAINER (page);
+#else
         container = TERMINAL_SCREEN_CONTAINER (gtk_notebook_get_nth_page (notebook, position));
+#endif
         screen = terminal_screen_container_get_screen (container);
 
 	action = g_object_get_data (G_OBJECT (screen), DATA_KEY);
